@@ -1,5 +1,5 @@
 /*
- * $Id: ad_open.c,v 1.19 2002/08/29 18:57:37 didg Exp $
+ * $Id: ad_open.c,v 1.19.2.1 2003/04/10 23:34:57 didg Exp $
  *
  * Copyright (c) 1999 Adrian Sun (asun@u.washington.edu)
  * Copyright (c) 1990,1991 Regents of The University of Michigan.
@@ -626,7 +626,7 @@ int ad_open( path, adflags, oflags, mode, ad )
 	  hoflags = (oflags & ~(O_RDONLY | O_WRONLY)) | O_RDWR;
 	  admode = ad_mode( path, mode ); 
 	  if (( ad->ad_df.adf_fd = open( path, hoflags, admode )) < 0 ) {
-             if (errno == EACCES && !(oflags & O_RDWR)) {
+             if ((errno == EACCES || errno == EROFS) && !(oflags & O_RDWR)) {
                 hoflags = oflags;
                 ad->ad_df.adf_fd =open( path, hoflags, admode );
              }
@@ -641,7 +641,7 @@ int ad_open( path, adflags, oflags, mode, ad )
             if ((oflags & ( O_RDWR | O_WRONLY)) &&             /* we want write access */
             	!(ad->ad_df.adf_flags & ( O_RDWR | O_WRONLY))) /* and it was denied the first time */
             {
-                 errno == EACCES;
+                 errno = EACCES;
                  return -1;
             }
 	}
@@ -655,7 +655,7 @@ int ad_open( path, adflags, oflags, mode, ad )
 	  hoflags = oflags & ~O_CREAT;
 	  hoflags = (hoflags & ~(O_RDONLY | O_WRONLY)) | O_RDWR;
 	  if (( ad->ad_hf.adf_fd = open( ad_p, hoflags, 0 )) < 0 ) {
-            if (errno == EACCES && !(oflags & O_RDWR)) {
+            if ((errno == EACCES || errno == EROFS) && !(oflags & O_RDWR)) {
                 hoflags = oflags & ~O_CREAT;
                 ad->ad_hf.adf_fd = open( ad_p, hoflags, 0 );
             }    
@@ -799,7 +799,7 @@ int ad_open( path, adflags, oflags, mode, ad )
               	    /* don't call with ADFLAGS_HF because we didn't open ressource fork */
 	            ad_close( ad, ADFLAGS_DF );
 	         }
-                 errno == EACCES;
+                 errno = EACCES;
 	         return -1;
 	    }
 	}
